@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::ChangeStats::Git;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: add code churn statistics to the changelog
-$Dist::Zilla::Plugin::ChangeStats::Git::VERSION = '0.5.0';
+$Dist::Zilla::Plugin::ChangeStats::Git::VERSION = '0.5.1';
 
 use strict;
 use warnings;
@@ -130,7 +130,7 @@ sub _get_comparison_data {
 			# binary files get '-' for insertions/deletions
 			++$data->{'files'};
 			$data->{'insertions'} += $insertions =~ m{^\d+$} ? $insertions : 0;
-			$data->{'deletions'} += $deletions =~ m{^\d+$} ? $insertions : 0;
+			$data->{'deletions'} += $deletions =~ m{^\d+$} ? $deletions : 0;
 		}
 
 		$output = sprintf '%d file%s changed, %d insertion%s(+), %d deletion%s(-)',
@@ -218,7 +218,7 @@ Dist::Zilla::Plugin::ChangeStats::Git - add code churn statistics to the changel
 
 =head1 VERSION
 
-version 0.5.0
+version 0.5.1
 
 =head1 SYNOPSIS
 
